@@ -12,7 +12,10 @@
   (defvar temp-cmdbuf)
   (defvar temp-bt)
   (defvar realgud-pat-hash)
-)
+  )
+
+(if (or (<= emacs-major-version 24))
+    (defalias 'font-lock-ensure 'font-lock-fontify-buffer))
 
 (defun setup-bt-vars(debugger-name)
   "Sets up globals temp-cmdbuf and temp-bt with command buffer
@@ -25,7 +28,8 @@ for DEBUGGER-NAME"
 		      (gethash debugger-name realgud-pat-hash))
 
     (switch-to-buffer nil)
-  ))
+    )
+  temp-cmdbuf)
 
 
 (defun setup-bt(debugger-name string)
@@ -37,7 +41,7 @@ for DEBUGGER-NAME and initializes it to STRING"
     (goto-char (point-min))
     (setq buffer-read-only nil)
     (insert string)
-    (font-lock-fontify-buffer)
+    (font-lock-ensure)
     ;; Newer emacs's use:
     (goto-char (point-min))
     )
